Mixed-Up Code Exercises
-----------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: mucp_15_1_sq
   :fromid: mucp_15_1, mucp_15_1_ac_q
   :toggle:

.. selectquestion:: mucp_15_2_sq
   :fromid: mucp_15_2, mucp_15_2_ac_q
   :toggle:

.. selectquestion:: mucp_15_3_sq
   :fromid: mucp_15_3, mucp_15_3_ac_q
   :toggle:

.. selectquestion:: mucp_15_4_sq
   :fromid: mucp_15_4, mucp_15_4_ac_q
   :toggle:

.. selectquestion:: mucp_15_5_sq
   :fromid: mucp_15_5, mucp_15_5_ac_q
   :toggle:

.. selectquestion:: mucp_15_6_sq
   :fromid: mucp_15_6, mucp_15_6_ac_q
   :toggle:

.. selectquestion:: mucp_15_7_sq
   :fromid: mucp_15_7, mucp_15_7_ac_q
   :toggle:

.. selectquestion:: mucp_15_8_sq
   :fromid: mucp_15_8, mucp_15_8_ac_q
   :toggle:

.. selectquestion:: mucp_15_9_sq
   :fromid: mucp_15_9, mucp_15_9_ac_q
   :toggle:

.. selectquestion:: mucp_15_10_sq
   :fromid: mucp_15_10, mucp_15_10_ac_q
   :toggle:
